==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetAllegroSummaryInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroSummaryInteractions]
(
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				VARCHAR(50),
	@EndHour				VARCHAR(50),
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					Int,
	@TypeInteraction		VARCHAR(MAX),
	@Origin					VARCHAR(MAX),
	@MinDuration			Int,
	@MaxDuration			Int,
	@EvaluationFormat		VARCHAR(50) = NULL,
	@Format					VARCHAR(50) = NULL
)
AS
BEGIN

	DECLARE @Sql NVARCHAR(MAX)

	-- SETTEAMOS UN VALOR POR DEFECTO AL FORMAT
	IF @Format IS NULL SET @Format = 'mp3, wav'

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TblHistoricalDataRef NVARCHAR(50) = '';
	DECLARE @TblMmprodataRef NVARCHAR(50) = '';

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TblHistoricalDataRef = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TblHistoricalDataRef = '[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[MMProDat].[dbo].'
	END

	SET @Sql = ''

	
	-- SE ARMA EL QUERY PRINCIPAL PARA LA BUSQUEDA DE INTERACCIONES Y TIEMPO TOTAL
	SET @Sql = 'SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)				''ID'',
						ISNULL(ID.[Id], 0)																							''TranscriptionId'',	--TOTAL DE INTEACCIONES
						ISNULL(ID.[AttentionTime], 0)																				''AttentionTime'',		-- TIEMPO TOTAL DE LOS AUDIOS
						RN = ROW_NUMBER() OVER(PARTITION BY (ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)) ORDER BY ID.[Id])
		FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
		LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
			ON ID.[Id] = IMP.[Id]
		LEFT JOIN (SELECT VCC, [CampaignID], [Order], [Code], [Description], [Category1], [Category2], [Category3 ]
					FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
					WHERE VCC = ''' + @VCC + ''') CGRM  
			ON CGRM.[VCC] = ID.[VirtualCC] 
				AND CGRM.[CampaignId] = ID.[Campaign] 
				AND CGRM.[Description] = ID.[ManagementResult] 
		WHERE ID.[VirtualCC] = ''' + @VCC + '''
			AND ID.Id IS NOT NULL
			AND ID.[EndDate] >= ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + '''
			AND ID.[EndDate] <= ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
			-- AND IMP.[Format] in (''mp3'', ''wav'') 
			AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Format + ''','','')) '
		
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
		SET @Sql += '
			AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
		SET @Sql += '
			AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF(@Campaign IS NOT NULL AND @Campaign <> '') 
		SET @Sql += '
			AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

	IF(@Agent IS NOT NULL AND @Agent <> '') 
		SET @Sql += '
			AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

	IF(@Origin IS NOT NULL AND @Origin <> '') 
		SET @Sql += '
			AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

	IF(@MinDuration IS NOT NULL) 
		SET @Sql += '
			AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

	IF(@MaxDuration IS NOT NULL) 
		SET @Sql += '
			AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

	IF(@ResultCode IS NOT NULL AND @ResultCode <> '')
		SET @Sql += ' 
			AND (
				(CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))) 
				OR
				(ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')))
			)'

 	-- ARMAMOS EL QUERY FINAL PARA LOS RESULTADOS
	--SET @Sql = 'select count(HDD.Id) as ''quantity'',
	--					dbo.[ConvertHourMin](SUM(HDD.AttentionTime)) as ''time'' 
	--				from (' + @Sql + ') HDD '

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@TblHistoricalDataRef = '')  
	BEGIN
		-- SI SE TRATA DE UN TYPE DESCONOCIDO SE ENVIA UN RESULT 1
		SET @Sql = 'SELECT 1 AS ''result'''  
	END

	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_SUMMARY_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_SUMMARY_INTERACTIONS
		(
			Id VARCHAR(150),
			TranscriptionId VARCHAR(100),
			AttentionTime DECIMAL(18, 3),
			RN INT
		)
	END

	-- EJECUTAMOS EL QUERY Y DEPOSITAMOS EL RESULTADO EN UNA TABLA TEMPORAL
	INSERT INTO #TMP_HD_SUMMARY_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL)

	-- EJECUTAMOS LAS CONSULTAS
	SELECT ISNULL(COUNT(DISTINCT ID.[TranscriptionId]), 0)					'totalInteraction',	--TOTAL DE INTEACCIONES
			ISNULL(COUNT(*), 0)												'quantity',			-- TOTAL DE AUDIOS
			ISNULL(SUM(ID.[AttentionTime]), 0)								'timeQuantity',		-- TIEMPO TOTAL DE LOS AUDIOS
			ISNULL(dbo.[ConvertHourMin](SUM(ID.[AttentionTime])), 0)		'time'				-- TIEMPO TOTAL DE LOS AUDIOS EN FORMATO HH:MM:SS
		FROM #TMP_HD_SUMMARY_INTERACTIONS ID
		WHERE RN = 1

	-- ELIMINAMOS LA TABLA TEMPORARL
	DROP TABLE #TMP_HD_SUMMARY_INTERACTIONS

	/*
	SET @Sql = 'SET NOCOUNT ON 
		' + @Sql + ' 
		SET NOCOUNT OFF'
	*/
	-- EJECUTAMOS LA CONSULTA
	-- SELECT @Sql

	--EXEC (@Sql)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetAllegroSummaryInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroSummaryInteractions]
(
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				VARCHAR(50),
	@EndHour				VARCHAR(50),
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					Int,
	@TypeInteraction		VARCHAR(MAX),
	@Origin					VARCHAR(MAX),
	@MinDuration			Int,
	@MaxDuration			Int,
	@EvaluationFormat		VARCHAR(50) = NULL,
	@Format					VARCHAR(50) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL
)
AS
BEGIN

	DECLARE @Sql NVARCHAR(MAX)

	-- SETTEAMOS UN VALOR POR DEFECTO AL FORMAT
	IF @Format IS NULL SET @Format = 'mp3, wav'

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TblHistoricalDataRef NVARCHAR(50) = '';
	DECLARE @TblMmprodataRef NVARCHAR(50) = '';
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TblHistoricalDataRef = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TblHistoricalDataRef = '[HistoricalData].[dbo].'
		SET @TblMmprodataRef = '[MMProDat].[dbo].'
	END
	
	-- SE ARMA EL QUERY PRINCIPAL PARA LA BUSQUEDA DE INTERACCIONES Y TIEMPO TOTAL
	SET @Sql = 'SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)				''ID'',
						ISNULL(ID.[Id], 0)																							''TranscriptionId'',	--TOTAL DE INTEACCIONES
						ISNULL(ID.[AttentionTime], 0)																				''AttentionTime'',		-- TIEMPO TOTAL DE LOS AUDIOS
						RN = ROW_NUMBER() OVER(PARTITION BY (ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)) ORDER BY ID.[Id])
		FROM ' + @TblHistoricalDataRef + '[InteractionMultimediaParts] IMP (NOLOCK)
		LEFT JOIN ' + @TblHistoricalDataRef + '[InteractionDetail] ID (NOLOCK) 
			ON ID.[Id] = IMP.[Id]
		LEFT JOIN (SELECT VCC, [CampaignID], [Order], [Code], [Description], [Category1], [Category2], [Category3 ]
					FROM ' + @TblMmprodataRef + '[CampaignGoalResultManagement] (NOLOCK)
					WHERE VCC = ''' + @VCC + ''') CGRM  
			ON CGRM.[VCC] = ID.[VirtualCC] 
				AND CGRM.[CampaignId] = ID.[Campaign] 
				AND CGRM.[Description] = ID.[ManagementResult] 
		WHERE ID.[VirtualCC] = ''' + @VCC + '''
			AND ID.Id IS NOT NULL ';

	SET @FILTERS_OPTIONAL_PART = ' AND ID.[EndDate] >= ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' ';
	SET @FILTERS_OPTIONAL_PART += ' AND ID.[EndDate] <= ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' ';
    SET @FILTERS_OPTIONAL_PART += ' AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Format + ''','','')) ';

	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
		SET @FILTERS_OPTIONAL_PART += '
			AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
		SET @FILTERS_OPTIONAL_PART += '
			AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF(@Campaign IS NOT NULL AND @Campaign <> '') 
		SET @FILTERS_OPTIONAL_PART += '
			AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) ';

	IF(@Agent IS NOT NULL AND @Agent <> '') 
		SET @FILTERS_OPTIONAL_PART += '
			AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) ';

	IF(@Origin IS NOT NULL AND @Origin <> '') 
		SET @FILTERS_OPTIONAL_PART += '
			AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) ';

	IF(@MinDuration IS NOT NULL) 
		SET @FILTERS_OPTIONAL_PART += '
			AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' ';

	IF(@MaxDuration IS NOT NULL) 
		SET @FILTERS_OPTIONAL_PART += '
			AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' ';

	IF(@ResultCode IS NOT NULL AND @ResultCode <> '')
		SET @FILTERS_OPTIONAL_PART += ' 
			AND (
				(CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))) 
				OR
				(ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')))
			)'

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
       SET @FILTERS_OPTIONAL_PART = '';
	   SET @FILTERS_EXCLUDING_PART = ' AND ID.[Id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
    END

    SET @Sql += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;
 	-- ARMAMOS EL QUERY FINAL PARA LOS RESULTADOS
	--SET @Sql = 'select count(HDD.Id) as ''quantity'',
	--					dbo.[ConvertHourMin](SUM(HDD.AttentionTime)) as ''time'' 
	--				from (' + @Sql + ') HDD '

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@TblHistoricalDataRef = '')  
	BEGIN
		-- SI SE TRATA DE UN TYPE DESCONOCIDO SE ENVIA UN RESULT 1
		SET @Sql = 'SELECT 1 AS ''result'''  
	END

	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_SUMMARY_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_SUMMARY_INTERACTIONS
		(
			Id VARCHAR(150),
			TranscriptionId VARCHAR(100),
			AttentionTime DECIMAL(18, 3),
			RN INT
		)
	END

	-- EJECUTAMOS EL QUERY Y DEPOSITAMOS EL RESULTADO EN UNA TABLA TEMPORAL
	INSERT INTO #TMP_HD_SUMMARY_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL)

	-- EJECUTAMOS LAS CONSULTAS
	SELECT ISNULL(COUNT(DISTINCT ID.[TranscriptionId]), 0)					'totalInteraction',	--TOTAL DE INTEACCIONES
			ISNULL(COUNT(*), 0)												'quantity',			-- TOTAL DE AUDIOS
			ISNULL(SUM(ID.[AttentionTime]), 0)								'timeQuantity',		-- TIEMPO TOTAL DE LOS AUDIOS
			ISNULL(dbo.[ConvertHourMin](SUM(ID.[AttentionTime])), 0)		'time'				-- TIEMPO TOTAL DE LOS AUDIOS EN FORMATO HH:MM:SS
		FROM #TMP_HD_SUMMARY_INTERACTIONS ID
		WHERE RN = 1

	-- ELIMINAMOS LA TABLA TEMPORARL
	DROP TABLE #TMP_HD_SUMMARY_INTERACTIONS

	/*
	SET @Sql = 'SET NOCOUNT ON 
		' + @Sql + ' 
		SET NOCOUNT OFF'
	*/
	-- EJECUTAMOS LA CONSULTA
	-- SELECT @Sql

	--EXEC (@Sql)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
